@@ -96,8 +96,8 @@ class BaseVolMesh(HalfFace):
 
         Parameters
         ----------
-        filepath : str
-            The path to the file.
+        filepath : path string, file-like object or URL string
+            A path, a file-like object or a URL pointing to a file.
         precision: str, optional
             The precision of the geometric map that is used to connect the lines.
 
@@ -127,8 +127,8 @@ class BaseVolMesh(HalfFace):
 
         Parameters
         ----------
-        filepath : str
-            Full path of the file.
+        filepath : path string or file-like object
+            A path or a file-like object pointing to a file.
         precision: str, optional
             The precision of the geometric map that is used to connect the lines.
         unweld : bool, optional
@@ -450,6 +450,21 @@ class BaseVolMesh(HalfFace):
     # face geometry
     # --------------------------------------------------------------------------
 
+    def face_vertices(self, face):
+        """The vertices of a face.
+
+        Parameters
+        ----------
+        halfface : int
+            The identifier of the face.
+
+        Returns
+        -------
+        list
+            Ordered vertex identifiers.
+        """
+        return self.halfface_vertices(face)
+
     def face_coordinates(self, face):
         """Compute the coordinates of the vertices of a face.
 
@@ -587,13 +602,13 @@ class BaseVolMesh(HalfFace):
         face_edge_lengths = [self.edge_length(edge) for edge in self.face_halfedges(face)]
         return max(face_edge_lengths) / min(face_edge_lengths)
 
-    # face_area = face_area
-    # face_centroid = face_centroid
-    # face_center = face_center
-    # face_coordinates = face_coordinates
-    # face_flatness = face_flatness
-    # face_normal = face_normal
-    # face_aspect_ratio = face_aspect_ratio
+    halfface_area = face_area
+    halfface_centroid = face_centroid
+    halfface_center = face_center
+    halfface_coordinates = face_coordinates
+    halfface_flatness = face_flatness
+    halfface_normal = face_normal
+    halfface_aspect_ratio = face_aspect_ratio
 
     # --------------------------------------------------------------------------
     # cell geometry
